==> QLC%2B_4.12.6.tar.gz: qlcplus-QLC-_4.12.6/plugins/E1.31/E131_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ConfigureE131</name>
    <message>
        <location filename="configuree131.ui" line="33"/>
        <source>Configure E1.31 Plugin</source>
        <translation>Configurar plugin E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Configuración de Universos</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="56"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="66"/>
        <source>Multicast</source>
        <translation>Multicast</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="71"/>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="76"/>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="81"/>
        <source>E1.31 Universe</source>
        <translation>Universo E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="86"/>
        <source>Transmission Mode</source>
        <translation>Modo de Transmisión</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="91"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="61"/>
        <source>Universe</source>
        <translation>Universo</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="86"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="92"/>
        <source>Outputs</source>
        <translation>Salidas</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="176"/>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="177"/>
        <source>Partial</source>
        <translation>Parcial</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="185"/>
        <source>%1 - min, %2 - default, %3 - max</source>
        <translation>%1 - mín, %2 - por defecto, %3 - máx</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="216"/>
        <source>Invalid IP</source>
        <translation>IP inválido</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="216"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 no es un IP válido
Por favor arréglelo antes de confirmar.</translation>
    </message>
</context>
<context>
    <name>E131Plugin</name>
    <message>
        <location filename="e131plugin.cpp" line="93"/>
        <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
        <translation>Este plugin provee salida DMX para dispositivos que soportan el protocolo de comunicación E1.31.</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="140"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="144"/>
        <location filename="e131plugin.cpp" line="284"/>
        <source>Status: Not open</source>
        <translation>Estado: No abierto</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="147"/>
        <location filename="e131plugin.cpp" line="287"/>
        <source>Status: Open</source>
        <translation>Estado: Abierto</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="149"/>
        <source>Packets sent: </source>
        <translation>Paquetes enviados: </translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="280"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="289"/>
        <source>Packets received: </source>
        <translation>Paquetes recibidos: </translation>
    </message>
</context>
</TS>

==> QLC%2B_4.14.0.tar.gz: qlcplus-QLC-_4.14.0/plugins/E1.31/E131_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ConfigureE131</name>
    <message>
        <location filename="configuree131.ui" line="33"/>
        <source>Configure E1.31 Plugin</source>
        <translation>Configurar plugin E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Configuración de Universos</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="56"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="66"/>
        <source>Multicast</source>
        <translation>Multicast</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="71"/>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="76"/>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="81"/>
        <source>E1.31 Universe</source>
        <translation>Universo E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="86"/>
        <source>Transmission Mode</source>
        <translation>Modo de Transmisión</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="91"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="101"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Segundos a esperar que esté preparada una interfaz</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="61"/>
        <source>Universe</source>
        <translation>Universo</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="99"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="105"/>
        <source>Outputs</source>
        <translation>Salidas</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="189"/>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="190"/>
        <source>Partial</source>
        <translation>Parcial</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="198"/>
        <source>%1 - min, %2 - default, %3 - max</source>
        <translation>%1 - mín, %2 - por defecto, %3 - máx</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="245"/>
        <source>Invalid IP</source>
        <translation>IP inválido</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="245"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 no es un IP válido
Por favor arréglelo antes de confirmar.</translation>
    </message>
</context>
<context>
    <name>E131Plugin</name>
    <message>
        <location filename="e131plugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
        <translation>Este plugin provee salida DMX para dispositivos que soportan el protocolo de comunicación E1.31.</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="144"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="148"/>
        <location filename="e131plugin.cpp" line="287"/>
        <source>Status: Not open</source>
        <translation>Estado: No abierto</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="151"/>
        <location filename="e131plugin.cpp" line="290"/>
        <source>Status: Open</source>
        <translation>Estado: Abierto</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="153"/>
        <source>Packets sent: </source>
        <translation>Paquetes enviados: </translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="283"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="292"/>
        <source>Packets received: </source>
        <translation>Paquetes recibidos: </translation>
    </message>
</context>
</TS>
